import numpy as np


def direct_ad(V_V, D_V, O_V, V_i, D_i, O_i, Pi_full, ss, T, tshocks):
    """Same signature as fakenews.curly, except that we specify shock times"""
    inputs = list(V_i.keys())
    outputs = list(O_V.keys())

    N_D = D_V.shape[0]

    Jpartial = {o.upper(): {i: np.empty((T, len(tshocks))) for i in inputs} for o in outputs}

    for i in inputs:
        for i_tshock, tshock in enumerate(tshocks):
            Ds = np.empty((tshock + 1, N_D))

            # initialize at shock
            Ds[tshock, :] = D_i[i]
            Os = {}
            for o in outputs:
                Os[o] = np.empty((tshock + 1, N_D))
                Os[o][tshock, :] = O_i[o][i]
            V = V_i[i]

            # backward iteration from tshock-1 to 0
            for t in reversed(range(tshock)):
                Ds[t, :] = D_V @ V
                for o in outputs:
                    Os[o][t, :] = O_V[o] @ V
                V = V_V @ V

            # forward iteration from 0 to T-1
            D = np.zeros(N_D)
            for t in range(T):
                for o in outputs:
                    Jpartial[o.upper()][i][t, i_tshock] = np.vdot(D, ss[o])
                    if t <= tshock:
                        Jpartial[o.upper()][i][t, i_tshock] += np.vdot(ss['D'], Os[o][t, :])
                D = Pi_full.T @ D
                if t <= tshock:
                    D += Ds[t, :]

    return Jpartial


def direct_diff_onesided(block, ss, T, inputs, tshocks, h=1E-4):
    results = {}
    for i in inputs:
        ghostrun = block.td(ss, **{i: np.full(T, ss[i])})
        for o in ghostrun:
            results.setdefault(o, {})[i] = np.empty((T, len(tshocks)))
        for c, tshock in enumerate(tshocks):
            out = block.td(ss, **{i: np.full(T, ss[i]) + h * (np.arange(T) == tshock)})
            for o in out:
                results[o][i][:, c] = (out[o] - ghostrun[o]) / h
    return results


def direct_diff_twosided(block, ss, T, inputs, tshocks, h=1E-4):
    results = {}
    for i in inputs:
        for c, tshock in enumerate(tshocks):
            out_up = block.td(ss, **{i: np.full(T, ss[i]) + h * (np.arange(T) == tshock)})
            out_down = block.td(ss, **{i: np.full(T, ss[i]) - h * (np.arange(T) == tshock)})
            for o in out_up:
                if i not in results.setdefault(o, {}):
                    results[o][i] = np.empty((T, len(tshocks)))
                results[o][i][:, c] = (out_up[o] - out_down[o]) / (2 * h)
    return results
