import jax.numpy as jnp
import numpy as np
from jax_utils import interpolate


def backward_iteration(Va_p, Pi_p, a_grid, e_grid, r, w, beta, eis):
    uc_nextgrid = (beta * Pi_p) @ Va_p
    return backward_iteration_endog(uc_nextgrid, a_grid, e_grid, r, w, eis)


def backward_iteration_endog(uc_nextgrid, a_grid, e_grid, r, w, eis):
    c_nextgrid = uc_nextgrid ** (-eis)
    coh = (1 + r) * a_grid[np.newaxis, :] + w * e_grid[:, np.newaxis]
    a = interpolate(coh, c_nextgrid + a_grid, a_grid)
    a = jnp.clip(a, a_grid[0])
    c = coh - a
    Va = (1 + r) * c ** (-1 / eis)
    return Va, a, c


def firm(K_L, L, Z, alpha, delta):
    r = alpha * Z * (K_L / L) ** (alpha - 1) - delta
    w = (1 - alpha) * Z * (K_L / L) ** alpha
    Y = Z * K_L ** alpha * L ** (1 - alpha)
    return r, w, Y
