
var y R pi z g gdp infl interest;
varexo epsR epsz epsg ;  
parameters tau beta kappa psi1 psi2 rho_r rho_z rho_g data_gamma data_pi data_r;

// Define parameters

tau = 2.83;
kappa = 0.78;
psi1 = 1.8;
psi2 = 0.63;
rho_r = 0.77;
rho_z = 0.88;
rho_g = 0.98;
data_gamma = 0.52;
data_pi = 3.3;
data_r = 0.42;
beta = 1/(1+data_r/400);

model(linear);

// Model equations

y = y(+1) - 1/tau*(R - pi(+1) - z(+1)) + g - g(+1);
pi = beta*pi(+1) + kappa*(y-g);
R = rho_r*R(-1) + (1-rho_r)*psi1*pi + (1-rho_r)*psi2*(y-g) + epsR;
z = rho_z*z(-1) + epsz;
g = rho_g*g(-1) + epsg;

// measurment equations

gdp = data_gamma + (y - y(-1) + z);
infl = data_pi + 4*pi;
interest = data_pi + data_r + 4*data_gamma + 4*R;

end; 

shocks;
var epsR;
stderr 0.22;
var epsz;
stderr 0.31;
var epsg;
stderr 0.71;
end;

// Estimation parameters

estimated_params;
// PARAM NAME, INITVAL, LB, UB, PRIOR_SHAPE, PRIOR_P1, PRIOR_P2, PRIOR_P3, PRIOR_P4, JSCALE
// PRIOR_SHAPE: BETA_PDF, GAMMA_PDF, NORMAL_PDF, INV_GAMMA_PDF, UNIFORM_PDF
tau, 2.83, 1, 5, GAMMA_PDF, 2, 0.5;
kappa, 0.78, 0.2, 1, UNIFORM_PDF,,,0,1;
psi1, 1.8, 1, 3, GAMMA_PDF, 1.5, 0.25;
psi2, 0.63, 0.1, 2, GAMMA_PDF, 0.5, 0.25;
rho_r, 0.77, 0.4, 0.9, UNIFORM_PDF,,,0,1;
rho_g, 0.98, 0.7, 0.999, UNIFORM_PDF,,,0,1;
rho_z, 0.88, 0.7, 0.99, UNIFORM_PDF,,,0,1;
stderr epsR, 0.22, 0.1, 0.4, INV_GAMMA_PDF, 0.5013256549262002,0.2620545510248134; 
stderr epsg, 0.71, 0.3, 0.99, INV_GAMMA_PDF, 1.2533141373155003,0.6551363775620335;
stderr epsz, 0.31, 0.01, 0.5, INV_GAMMA_PDF, 0.6266570686577502,0.32756818878101673; 
data_r, 0.42, 0.2, 0.8, GAMMA_PDF, 0.5, 0.5;
data_pi, 3.3, 2.5, 4, GAMMA_PDF, 7, 2;
data_gamma, 0.52, 0.04, 0.95, NORMAL_PDF, 0.4, 0.2;
end;

varobs gdp infl interest;

// Solve and estimate the model

// Solve the model with pre-defined parameters
stoch_simul(irf=100, nograph);

// Estimate parameters
//estimation(optim=('MaxIter',200),datafile=Bayes_hs_data_mat,mode_compute=1,first_obs=1, presample=4,lik_init=2,prefilter=0,mh_replic=0,mh_nblocks=2,mh_jscale=0.20,mh_drop=0.2, nograph, tex);
estimation(optim=('MaxIter',200),datafile=Bayes_hs_data_mat,mode_compute=1,mh_replic=0,nograph);
