function [residual, g1, g2, g3] = sw_dynarecode_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [nperiods by M_.exo_nbr] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   steady_state  [M_.endo_nbr by 1] double       vector of steady state values
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations.
%                                          Dynare may prepend auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(40, 1);
cpie__ = 1+params(4)/100;
cgamma__ = 1+params(35)/100;
cbeta__ = 1/(1+params(5)/100);
clandap__ = params(14);
cbetabar__ = cbeta__*cgamma__^(-params(10));
cr__ = cpie__/(cbeta__*cgamma__^(-params(10)));
crk__ = cbeta__^(-1)*cgamma__^params(10)-(1-params(9));
cw__ = (params(6)^params(6)*(1-params(6))^(1-params(6))/(clandap__*crk__^params(6)))^(1/(1-params(6)));
cikbar__ = 1-(1-params(9))/cgamma__;
cik__ = cgamma__*(1-(1-params(9))/cgamma__);
clk__ = (1-params(6))/params(6)*crk__/cw__;
cky__ = params(14)*clk__^(params(6)-1);
ciy__ = cik__*cky__;
ccy__ = 1-params(36)-cik__*cky__;
crkky__ = crk__*cky__;
cwhlc__ = cky__*crk__*(1-params(6))*1/params(20)/params(6)/ccy__;
conster__ = 100*(cr__-1);
T87 = 1/(params(7)/(1-params(7)));
T102 = 1/(1+cgamma__*cbetabar__);
T107 = cgamma__^2;
T109 = T107*params(8);
T122 = params(11)/cgamma__;
T126 = (1-T122)/(params(10)*(1+T122));
T135 = (1-params(9))/(1-params(9)+crk__);
T151 = (params(10)-1)*cwhlc__/(params(10)*(1+T122));
T179 = 1/(1-T122);
T182 = T122/(1-T122);
T271 = 1/(1+cgamma__*cbetabar__*params(17));
T286 = (1-params(18))*(1-cgamma__*cbetabar__*params(18))/params(18)/(1+(params(14)-1)*params(2));
T295 = cgamma__*cbetabar__/(1+cgamma__*cbetabar__);
T322 = (1-params(16))*(1-cgamma__*cbetabar__*params(16))/((1+cgamma__*cbetabar__)*params(16))*1/(1+(params(20)-1)*params(1));
lhs =y(50);
rhs =params(6)*y(29)+(1-params(6))*y(36);
residual(1)= lhs-rhs;
lhs =y(28);
rhs =y(29)*T87;
residual(2)= lhs-rhs;
lhs =y(29);
rhs =y(36)+y(35)-y(30);
residual(3)= lhs-rhs;
lhs =y(30);
rhs =y(28)+y(17);
residual(4)= lhs-rhs;
lhs =y(33);
rhs =T102*(y(2)+cgamma__*cbetabar__*y(64)+1/T109*y(31))+y(53);
residual(5)= lhs-rhs;
lhs =y(31);
rhs =(-y(37))+y(51)*1/T126+crk__/(1-params(9)+crk__)*y(61)+T135*y(62);
residual(6)= lhs-rhs;
lhs =y(32);
rhs =y(51)+T122/(1+T122)*y(1)+1/(1+T122)*y(63)+T151*(y(35)-y(65))-y(37)*T126;
residual(7)= lhs-rhs;
lhs =y(34);
rhs =ccy__*y(32)+y(33)*ciy__+y(52)+y(28)*crkky__;
residual(8)= lhs-rhs;
lhs =y(34);
rhs =params(14)*(y(50)+params(6)*y(30)+(1-params(6))*y(35));
residual(9)= lhs-rhs;
lhs =y(36);
rhs =y(35)*params(19)+y(32)*T179-y(1)*T182;
residual(10)= lhs-rhs;
lhs =y(57);
rhs =y(17)*(1-cikbar__)+y(33)*cikbar__+y(53)*T109*cikbar__;
residual(11)= lhs-rhs;
lhs =y(38);
rhs =params(6)*y(40)+(1-params(6))*y(48)-y(50);
residual(12)= lhs-rhs;
lhs =y(39);
rhs =T87*y(40);
residual(13)= lhs-rhs;
lhs =y(40);
rhs =y(48)+y(46)-y(41);
residual(14)= lhs-rhs;
lhs =y(41);
rhs =y(39)+y(18);
residual(15)= lhs-rhs;
lhs =y(44);
rhs =y(53)+T102*(y(5)+cgamma__*cbetabar__*y(69)+1/T109*y(42));
residual(16)= lhs-rhs;
lhs =y(42);
rhs =y(51)*1/T126+(-y(49))+y(71)+crk__/(1-params(9)+crk__)*y(66)+T135*y(67);
residual(17)= lhs-rhs;
lhs =y(43);
rhs =y(51)+T122/(1+T122)*y(4)+1/(1+T122)*y(68)+T151*(y(46)-y(70))-T126*(y(49)-y(71));
residual(18)= lhs-rhs;
lhs =y(45);
rhs =y(52)+ccy__*y(43)+ciy__*y(44)+crkky__*y(39);
residual(19)= lhs-rhs;
lhs =y(45);
rhs =params(14)*(y(50)+params(6)*y(41)+(1-params(6))*y(46));
residual(20)= lhs-rhs;
lhs =y(47);
rhs =T271*(cgamma__*cbetabar__*y(71)+params(17)*y(7)+y(38)*T286)+y(55);
residual(21)= lhs-rhs;
lhs =y(48);
rhs =T102*y(8)+T295*y(72)+y(7)*params(15)/(1+cgamma__*cbetabar__)-y(47)*(1+cgamma__*cbetabar__*params(15))/(1+cgamma__*cbetabar__)+y(71)*T295+T322*(params(19)*y(46)+T179*y(43)-T182*y(4)-y(48))+y(56);
residual(22)= lhs-rhs;
lhs =y(49);
rhs =y(47)*params(22)*(1-params(25))+(1-params(25))*params(24)*(y(45)-y(34))+params(23)*(y(45)-y(34)-y(6)+y(3))+params(25)*y(9)+y(54);
residual(23)= lhs-rhs;
lhs =y(50);
rhs =params(26)*y(10)+x(it_, 1);
residual(24)= lhs-rhs;
lhs =y(51);
rhs =params(27)*y(11)+x(it_, 2);
residual(25)= lhs-rhs;
lhs =y(52);
rhs =params(28)*y(12)+x(it_, 3);
residual(26)= lhs-rhs;
lhs =y(53);
rhs =params(29)*y(13)+x(it_, 4);
residual(27)= lhs-rhs;
lhs =y(54);
rhs =params(30)*y(14)+x(it_, 5);
residual(28)= lhs-rhs;
lhs =y(55);
rhs =params(31)*y(15)+x(it_, 6)-params(34)*y(19);
residual(29)= lhs-rhs;
lhs =y(56);
rhs =params(32)*y(16)+x(it_, 7)-params(33)*y(20);
residual(30)= lhs-rhs;
lhs =y(58);
rhs =(1-cikbar__)*y(18)+cikbar__*y(44)+y(53)*params(8)*T107*cikbar__;
residual(31)= lhs-rhs;
lhs =y(24);
rhs =params(35)+y(45)-y(6);
residual(32)= lhs-rhs;
lhs =y(25);
rhs =params(35)+y(43)-y(4);
residual(33)= lhs-rhs;
lhs =y(26);
rhs =params(35)+y(44)-y(5);
residual(34)= lhs-rhs;
lhs =y(27);
rhs =params(35)+y(48)-y(8);
residual(35)= lhs-rhs;
lhs =y(23);
rhs =params(4)+y(47);
residual(36)= lhs-rhs;
lhs =y(22);
rhs =y(49)+conster__;
residual(37)= lhs-rhs;
lhs =y(21);
rhs =y(46)+params(3);
residual(38)= lhs-rhs;
lhs =y(59);
rhs =x(it_, 6);
residual(39)= lhs-rhs;
lhs =y(60);
rhs =x(it_, 7);
residual(40)= lhs-rhs;
if nargout >= 2,
  g1 = zeros(40, 79);

  %
  % Jacobian matrix
  %

  g1(1,29)=(-params(6));
  g1(1,36)=(-(1-params(6)));
  g1(1,50)=1;
  g1(2,28)=1;
  g1(2,29)=(-T87);
  g1(3,29)=1;
  g1(3,30)=1;
  g1(3,35)=(-1);
  g1(3,36)=(-1);
  g1(4,28)=(-1);
  g1(4,30)=1;
  g1(4,17)=(-1);
  g1(5,31)=(-(T102*1/T109));
  g1(5,2)=(-T102);
  g1(5,33)=1;
  g1(5,64)=(-(cgamma__*cbetabar__*T102));
  g1(5,53)=(-1);
  g1(6,61)=(-(crk__/(1-params(9)+crk__)));
  g1(6,31)=1;
  g1(6,62)=(-T135);
  g1(6,37)=1;
  g1(6,51)=(-(1/T126));
  g1(7,1)=(-(T122/(1+T122)));
  g1(7,32)=1;
  g1(7,63)=(-(1/(1+T122)));
  g1(7,35)=(-T151);
  g1(7,65)=T151;
  g1(7,37)=T126;
  g1(7,51)=(-1);
  g1(8,28)=(-crkky__);
  g1(8,32)=(-ccy__);
  g1(8,33)=(-ciy__);
  g1(8,34)=1;
  g1(8,52)=(-1);
  g1(9,30)=(-(params(14)*params(6)));
  g1(9,34)=1;
  g1(9,35)=(-(params(14)*(1-params(6))));
  g1(9,50)=(-params(14));
  g1(10,1)=T182;
  g1(10,32)=(-T179);
  g1(10,35)=(-params(19));
  g1(10,36)=1;
  g1(11,33)=(-cikbar__);
  g1(11,53)=(-(T109*cikbar__));
  g1(11,17)=(-(1-cikbar__));
  g1(11,57)=1;
  g1(12,38)=1;
  g1(12,40)=(-params(6));
  g1(12,48)=(-(1-params(6)));
  g1(12,50)=1;
  g1(13,39)=1;
  g1(13,40)=(-T87);
  g1(14,40)=1;
  g1(14,41)=1;
  g1(14,46)=(-1);
  g1(14,48)=(-1);
  g1(15,39)=(-1);
  g1(15,41)=1;
  g1(15,18)=(-1);
  g1(16,42)=(-(T102*1/T109));
  g1(16,5)=(-T102);
  g1(16,44)=1;
  g1(16,69)=(-(cgamma__*cbetabar__*T102));
  g1(16,53)=(-1);
  g1(17,66)=(-(crk__/(1-params(9)+crk__)));
  g1(17,42)=1;
  g1(17,67)=(-T135);
  g1(17,71)=(-1);
  g1(17,49)=1;
  g1(17,51)=(-(1/T126));
  g1(18,4)=(-(T122/(1+T122)));
  g1(18,43)=1;
  g1(18,68)=(-(1/(1+T122)));
  g1(18,46)=(-T151);
  g1(18,70)=T151;
  g1(18,71)=(-T126);
  g1(18,49)=T126;
  g1(18,51)=(-1);
  g1(19,39)=(-crkky__);
  g1(19,43)=(-ccy__);
  g1(19,44)=(-ciy__);
  g1(19,45)=1;
  g1(19,52)=(-1);
  g1(20,41)=(-(params(14)*params(6)));
  g1(20,45)=1;
  g1(20,46)=(-(params(14)*(1-params(6))));
  g1(20,50)=(-params(14));
  g1(21,38)=(-(T271*T286));
  g1(21,7)=(-(params(17)*T271));
  g1(21,47)=1;
  g1(21,71)=(-(cgamma__*cbetabar__*T271));
  g1(21,55)=(-1);
  g1(22,4)=(-(T322*(-T182)));
  g1(22,43)=(-(T179*T322));
  g1(22,46)=(-(params(19)*T322));
  g1(22,7)=(-(params(15)/(1+cgamma__*cbetabar__)));
  g1(22,47)=(1+cgamma__*cbetabar__*params(15))/(1+cgamma__*cbetabar__);
  g1(22,71)=(-T295);
  g1(22,8)=(-T102);
  g1(22,48)=1-(-T322);
  g1(22,72)=(-T295);
  g1(22,56)=(-1);
  g1(23,3)=(-params(23));
  g1(23,34)=(-((-((1-params(25))*params(24)))-params(23)));
  g1(23,6)=params(23);
  g1(23,45)=(-((1-params(25))*params(24)+params(23)));
  g1(23,47)=(-(params(22)*(1-params(25))));
  g1(23,9)=(-params(25));
  g1(23,49)=1;
  g1(23,54)=(-1);
  g1(24,10)=(-params(26));
  g1(24,50)=1;
  g1(24,73)=(-1);
  g1(25,11)=(-params(27));
  g1(25,51)=1;
  g1(25,74)=(-1);
  g1(26,12)=(-params(28));
  g1(26,52)=1;
  g1(26,75)=(-1);
  g1(27,13)=(-params(29));
  g1(27,53)=1;
  g1(27,76)=(-1);
  g1(28,14)=(-params(30));
  g1(28,54)=1;
  g1(28,77)=(-1);
  g1(29,15)=(-params(31));
  g1(29,55)=1;
  g1(29,78)=(-1);
  g1(29,19)=params(34);
  g1(30,16)=(-params(32));
  g1(30,56)=1;
  g1(30,79)=(-1);
  g1(30,20)=params(33);
  g1(31,44)=(-cikbar__);
  g1(31,53)=(-(params(8)*T107*cikbar__));
  g1(31,18)=(-(1-cikbar__));
  g1(31,58)=1;
  g1(32,24)=1;
  g1(32,6)=1;
  g1(32,45)=(-1);
  g1(33,25)=1;
  g1(33,4)=1;
  g1(33,43)=(-1);
  g1(34,26)=1;
  g1(34,5)=1;
  g1(34,44)=(-1);
  g1(35,27)=1;
  g1(35,8)=1;
  g1(35,48)=(-1);
  g1(36,23)=1;
  g1(36,47)=(-1);
  g1(37,22)=1;
  g1(37,49)=(-1);
  g1(38,21)=1;
  g1(38,46)=(-1);
  g1(39,78)=(-1);
  g1(39,59)=1;
  g1(40,79)=(-1);
  g1(40,60)=1;

if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],40,6241);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],40,493039);
end
end
end
end
