function [residual, g1, g2, g3] = sw_dynarecode_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations.
%                                          Dynare may prepend or append auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g3        [M_.endo_nbr by (M_.endo_nbr)^3] double   Third derivatives matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 40, 1);

%
% Model equations
%

cpie__ = 1+params(4)/100;
cgamma__ = 1+params(35)/100;
cbeta__ = 1/(1+params(5)/100);
clandap__ = params(14);
cbetabar__ = cbeta__*cgamma__^(-params(10));
cr__ = cpie__/(cbeta__*cgamma__^(-params(10)));
crk__ = cbeta__^(-1)*cgamma__^params(10)-(1-params(9));
cw__ = (params(6)^params(6)*(1-params(6))^(1-params(6))/(clandap__*crk__^params(6)))^(1/(1-params(6)));
cikbar__ = 1-(1-params(9))/cgamma__;
cik__ = cgamma__*(1-(1-params(9))/cgamma__);
clk__ = (1-params(6))/params(6)*crk__/cw__;
cky__ = params(14)*clk__^(params(6)-1);
ciy__ = cik__*cky__;
ccy__ = 1-params(36)-cik__*cky__;
crkky__ = crk__*cky__;
conster__ = 100*(cr__-1);
T87 = 1/(params(7)/(1-params(7)));
T102 = 1/(1+cgamma__*cbetabar__);
T105 = cgamma__^2;
T107 = T105*params(8);
T120 = params(11)/cgamma__;
T124 = (1-T120)/(params(10)*(1+T120));
T132 = (1-params(9))/(1-params(9)+crk__);
T249 = 1/(1+cgamma__*cbetabar__*params(17));
T263 = (1-params(18))*(1-cgamma__*cbetabar__*params(18))/params(18)/(1+(params(14)-1)*params(2));
T271 = cgamma__*cbetabar__/(1+cgamma__*cbetabar__);
T297 = (1-params(16))*(1-cgamma__*cbetabar__*params(16))/((1+cgamma__*cbetabar__)*params(16))*1/(1+(params(20)-1)*params(1));
lhs =y(30);
rhs =params(6)*y(9)+(1-params(6))*y(16);
residual(1)= lhs-rhs;
lhs =y(8);
rhs =y(9)*T87;
residual(2)= lhs-rhs;
lhs =y(9);
rhs =y(16)+y(15)-y(10);
residual(3)= lhs-rhs;
lhs =y(10);
rhs =y(8)+y(37);
residual(4)= lhs-rhs;
lhs =y(13);
rhs =T102*(y(13)+y(13)*cgamma__*cbetabar__+1/T107*y(11))+y(33);
residual(5)= lhs-rhs;
lhs =y(11);
rhs =(-y(17))+y(31)*1/T124+y(9)*crk__/(1-params(9)+crk__)+y(11)*T132;
residual(6)= lhs-rhs;
lhs =y(12);
rhs =y(31)+y(12)*T120/(1+T120)+y(12)*1/(1+T120)-y(17)*T124;
residual(7)= lhs-rhs;
lhs =y(14);
rhs =ccy__*y(12)+y(13)*ciy__+y(32)+y(8)*crkky__;
residual(8)= lhs-rhs;
lhs =y(14);
rhs =params(14)*(y(30)+params(6)*y(10)+(1-params(6))*y(15));
residual(9)= lhs-rhs;
lhs =y(16);
rhs =y(15)*params(19)+y(12)*1/(1-T120)-y(12)*T120/(1-T120);
residual(10)= lhs-rhs;
lhs =y(37);
rhs =y(37)*(1-cikbar__)+y(13)*cikbar__+y(33)*T107*cikbar__;
residual(11)= lhs-rhs;
lhs =y(18);
rhs =params(6)*y(20)+(1-params(6))*y(28)-y(30);
residual(12)= lhs-rhs;
lhs =y(19);
rhs =T87*y(20);
residual(13)= lhs-rhs;
lhs =y(20);
rhs =y(28)+y(26)-y(21);
residual(14)= lhs-rhs;
lhs =y(21);
rhs =y(19)+y(38);
residual(15)= lhs-rhs;
lhs =y(24);
rhs =y(33)+T102*(y(24)+cgamma__*cbetabar__*y(24)+1/T107*y(22));
residual(16)= lhs-rhs;
lhs =y(22);
rhs =y(31)*1/T124+(-y(29))+y(27)+crk__/(1-params(9)+crk__)*y(20)+T132*y(22);
residual(17)= lhs-rhs;
lhs =y(23);
rhs =y(31)+T120/(1+T120)*y(23)+1/(1+T120)*y(23)-T124*(y(29)-y(27));
residual(18)= lhs-rhs;
lhs =y(25);
rhs =y(32)+ccy__*y(23)+ciy__*y(24)+crkky__*y(19);
residual(19)= lhs-rhs;
lhs =y(25);
rhs =params(14)*(y(30)+params(6)*y(21)+(1-params(6))*y(26));
residual(20)= lhs-rhs;
lhs =y(27);
rhs =T249*(cgamma__*cbetabar__*y(27)+y(27)*params(17)+y(18)*T263)+y(35);
residual(21)= lhs-rhs;
lhs =y(28);
rhs =T102*y(28)+y(28)*T271+y(27)*params(15)/(1+cgamma__*cbetabar__)-y(27)*(1+cgamma__*cbetabar__*params(15))/(1+cgamma__*cbetabar__)+y(27)*T271+T297*(params(19)*y(26)+1/(1-T120)*y(23)-T120/(1-T120)*y(23)-y(28))+y(36);
residual(22)= lhs-rhs;
lhs =y(29);
rhs =y(27)*params(22)*(1-params(25))+(1-params(25))*params(24)*(y(25)-y(14))+params(23)*(y(14)+y(25)-y(14)-y(25))+y(29)*params(25)+y(34);
residual(23)= lhs-rhs;
lhs =y(30);
rhs =y(30)*params(26)+x(1);
residual(24)= lhs-rhs;
lhs =y(31);
rhs =y(31)*params(27)+x(2);
residual(25)= lhs-rhs;
lhs =y(32);
rhs =y(32)*params(28)+x(3);
residual(26)= lhs-rhs;
lhs =y(33);
rhs =y(33)*params(29)+x(4);
residual(27)= lhs-rhs;
lhs =y(34);
rhs =y(34)*params(30)+x(5);
residual(28)= lhs-rhs;
lhs =y(35);
rhs =y(35)*params(31)+x(6)-x(6)*params(34);
residual(29)= lhs-rhs;
lhs =y(36);
rhs =y(36)*params(32)+x(7)-x(7)*params(33);
residual(30)= lhs-rhs;
lhs =y(38);
rhs =(1-cikbar__)*y(38)+cikbar__*y(24)+y(33)*params(8)*T105*cikbar__;
residual(31)= lhs-rhs;
lhs =y(4);
rhs =params(35);
residual(32)= lhs-rhs;
lhs =y(5);
rhs =params(35);
residual(33)= lhs-rhs;
lhs =y(6);
rhs =params(35);
residual(34)= lhs-rhs;
lhs =y(7);
rhs =params(35);
residual(35)= lhs-rhs;
lhs =y(3);
rhs =params(4)+y(27);
residual(36)= lhs-rhs;
lhs =y(2);
rhs =y(29)+conster__;
residual(37)= lhs-rhs;
lhs =y(1);
rhs =y(26)+params(3);
residual(38)= lhs-rhs;
lhs =y(39);
rhs =x(6);
residual(39)= lhs-rhs;
lhs =y(40);
rhs =x(7);
residual(40)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(40, 40);

  %
  % Jacobian matrix
  %

T423 = 1-(T120/(1+T120)+1/(1+T120));
T425 = 1/(1-T120)-T120/(1-T120);
  g1(1,9)=(-params(6));
  g1(1,16)=(-(1-params(6)));
  g1(1,30)=1;
  g1(2,8)=1;
  g1(2,9)=(-T87);
  g1(3,9)=1;
  g1(3,10)=1;
  g1(3,15)=(-1);
  g1(3,16)=(-1);
  g1(4,8)=(-1);
  g1(4,10)=1;
  g1(4,37)=(-1);
  g1(5,11)=(-(T102*1/T107));
  g1(5,13)=1-(1+cgamma__*cbetabar__)*T102;
  g1(5,33)=(-1);
  g1(6,9)=(-(crk__/(1-params(9)+crk__)));
  g1(6,11)=1-T132;
  g1(6,17)=1;
  g1(6,31)=(-(1/T124));
  g1(7,12)=T423;
  g1(7,17)=T124;
  g1(7,31)=(-1);
  g1(8,8)=(-crkky__);
  g1(8,12)=(-ccy__);
  g1(8,13)=(-ciy__);
  g1(8,14)=1;
  g1(8,32)=(-1);
  g1(9,10)=(-(params(14)*params(6)));
  g1(9,14)=1;
  g1(9,15)=(-(params(14)*(1-params(6))));
  g1(9,30)=(-params(14));
  g1(10,12)=(-T425);
  g1(10,15)=(-params(19));
  g1(10,16)=1;
  g1(11,13)=(-cikbar__);
  g1(11,33)=(-(T107*cikbar__));
  g1(11,37)=1-(1-cikbar__);
  g1(12,18)=1;
  g1(12,20)=(-params(6));
  g1(12,28)=(-(1-params(6)));
  g1(12,30)=1;
  g1(13,19)=1;
  g1(13,20)=(-T87);
  g1(14,20)=1;
  g1(14,21)=1;
  g1(14,26)=(-1);
  g1(14,28)=(-1);
  g1(15,19)=(-1);
  g1(15,21)=1;
  g1(15,38)=(-1);
  g1(16,22)=(-(T102*1/T107));
  g1(16,24)=1-(1+cgamma__*cbetabar__)*T102;
  g1(16,33)=(-1);
  g1(17,20)=(-(crk__/(1-params(9)+crk__)));
  g1(17,22)=1-T132;
  g1(17,27)=(-1);
  g1(17,29)=1;
  g1(17,31)=(-(1/T124));
  g1(18,23)=T423;
  g1(18,27)=(-T124);
  g1(18,29)=T124;
  g1(18,31)=(-1);
  g1(19,19)=(-crkky__);
  g1(19,23)=(-ccy__);
  g1(19,24)=(-ciy__);
  g1(19,25)=1;
  g1(19,32)=(-1);
  g1(20,21)=(-(params(14)*params(6)));
  g1(20,25)=1;
  g1(20,26)=(-(params(14)*(1-params(6))));
  g1(20,30)=(-params(14));
  g1(21,18)=(-(T249*T263));
  g1(21,27)=1-T249*(cgamma__*cbetabar__+params(17));
  g1(21,35)=(-1);
  g1(22,23)=(-(T297*T425));
  g1(22,26)=(-(params(19)*T297));
  g1(22,27)=(-(T271+params(15)/(1+cgamma__*cbetabar__)-(1+cgamma__*cbetabar__*params(15))/(1+cgamma__*cbetabar__)));
  g1(22,28)=1-(T102+T271-T297);
  g1(22,36)=(-1);
  g1(23,14)=(1-params(25))*params(24);
  g1(23,25)=(-((1-params(25))*params(24)));
  g1(23,27)=(-(params(22)*(1-params(25))));
  g1(23,29)=1-params(25);
  g1(23,34)=(-1);
  g1(24,30)=1-params(26);
  g1(25,31)=1-params(27);
  g1(26,32)=1-params(28);
  g1(27,33)=1-params(29);
  g1(28,34)=1-params(30);
  g1(29,35)=1-params(31);
  g1(30,36)=1-params(32);
  g1(31,24)=(-cikbar__);
  g1(31,33)=(-(params(8)*T105*cikbar__));
  g1(31,38)=1-(1-cikbar__);
  g1(32,4)=1;
  g1(33,5)=1;
  g1(34,6)=1;
  g1(35,7)=1;
  g1(36,3)=1;
  g1(36,27)=(-1);
  g1(37,2)=1;
  g1(37,29)=(-1);
  g1(38,1)=1;
  g1(38,26)=(-1);
  g1(39,39)=1;
  g1(40,40)=1;
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],40,1600);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],40,64000);
end
end
end
end
